[![Build Status](https://travis-ci.org/sz3/pogui.svg?branch=master)](https://travis-ci.org/sz3/pogui)
[![Coverage Status](https://coveralls.io/repos/github/sz3/pogui/badge.svg?branch=master)](https://coveralls.io/github/sz3/pogui?branch=master)

## Installation

From source,
```
python setup.py build
python setup.py install
```

On linux, you'll also want to make sure PyQtWebEngine is installed. For example, with:
```
pip install PyQt5 PyQtWebEngine
```

## Usage

python -m pogui.pogui
